## 股权质押统计数据

接口：pledge_stat

描述：获取股票质押统计数据

限量：单次最大1000

积分：用户需要至少500积分才可以调取，具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 股票代码 |
| end_date | str | N | 截止日期 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | TS代码 |
| end_date | str | Y | 截止日期 |
| pledge_count | int | Y | 质押次数 |
| unrest_pledge | float | Y | 无限售股质押数量（万） |
| rest_pledge | float | Y | 限售股份质押数量（万） |
| total_share | float | Y | 总股本 |
| pledge_ratio | float | Y | 质押比例 |

接口使用

```python
pro = ts.pro_api()
#或者
#pro = ts.pro_api('your token')


df = pro.pledge_stat(ts_code='000014.SZ')
```

或者

```python
df = pro.query('pledge_stat', ts_code='000014.SZ')
```

数据示例

```python
ts_code  end_date  pledge_count  unrest_pledge  rest_pledge  \
0    000014.SZ  20180928            23          63.16          0.0   
```